Index: components/html_viewer/web_cookie_jar_impl.cc |
diff --git a/components/html_viewer/web_cookie_jar_impl.cc b/components/html_viewer/web_cookie_jar_impl.cc |
index c59bfd2a75473426457d6c543f094d0a57342f38..019acfb089fe50a4e46e9e18b1b5c96fc45e8170 100644 |
--- a/components/html_viewer/web_cookie_jar_impl.cc |
+++ b/components/html_viewer/web_cookie_jar_impl.cc |
@@ -43,7 +43,7 @@ void WebCookieJarImpl::setCookie(const blink::WebURL& url, |
// and URLLoader, so that we could let this method call run asynchronously |
// without suffering an ordering problem. See crbug/386825. |
// |
- store_.WaitForIncomingResponse(); |
+ store_.WaitForIncomingMethodCall(); |
} |
blink::WebString WebCookieJarImpl::cookies( |
@@ -53,9 +53,9 @@ blink::WebString WebCookieJarImpl::cookies( |
store_->Get(url.string().utf8(), base::Bind(&CopyString, &result)); |
// Wait for the result. Since every outbound request we make to the cookie |
// store is followed up with WaitForIncomingResponse, we can be sure that |
// the next incoming method call will be the response to our request. |
- store_.WaitForIncomingResponse(); |
+ store_.WaitForIncomingMethodCall(); |
if (!result) |
return blink::WebString(); |
@@ -53,9 +53,9 @@ blink::WebString WebCookieJarImpl::cookies( |
store_->Get(url.string().utf8(), base::Bind(&CopyString, &result)); |
// Wait for the result. Since every outbound request we make to the cookie |
- // store is followed up with WaitForIncomingResponse, we can be sure that |
+ // store is followed up with WaitForIncomingMethodCall, we can be sure that |
// the next incoming method call will be the response to our request. |